@@ -1,12 +1,14 @@
 package App::lcpan::Cmd::doc;
 
-our $DATE = '2016-02-25'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2016-03-02'; # DATE
+our $VERSION = '0.81'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
+use Encode qw(decode);
+
 require App::lcpan;
 
 our %SPEC;
@@ -146,6 +148,7 @@ sub handle_cmd {
             } elsif ($ext eq 'pod') {
                 push @where, "path LIKE '%.pod'";
             }
+            push @where, ("NOT(file.name LIKE '%-Lumped-%')"); # tmp
             $row = $dbh->selectrow_hashref("SELECT
   content.path content_path,
   file.cpanid author,
@@ -162,6 +165,7 @@ LIMIT 1", {}, @bind);
                 # from content path
                 $name =~ s!::!/!g; $name .= ".pod";
                 @where = ("content.path LIKE ?");
+                push @where, ("NOT(file.name LIKE '%-Lumped-%')"); # tmp
                 @bind = ("%$name");
 
                 my $sth = $dbh->prepare("SELECT
@@ -184,6 +188,7 @@ ORDER BY content.size DESC");
         } elsif ($look eq 'script') {
 
             push @where, "script.name=?";
+            push @where, ("NOT(file.name LIKE '%-Lumped-%')"); # tmp
             $row = $dbh->selectrow_hashref("SELECT
   content.path content_path,
   file.cpanid author,
@@ -217,13 +222,18 @@ LIMIT 1", {}, @bind);
         my $tar;
         eval {
             $tar = Archive::Tar->new;
-            $tar->read($path); # can still die untrapped when out of mem
+            $content = $tar->read($path); # can still die untrapped when out of mem
         };
         return [500, "Can't read tar file '$path': $@"] if $@;
         my ($obj) = $tar->get_files($row->{content_path});
         $content = $obj->get_content;
     }
 
+    if ($content =~ /^=encoding\s+(utf-?8)/im) {
+        # doesn't seem necessary
+        #$content = decode('utf8', $content, Encode::FB_CROAK);
+    }
+
     if ($args{format} eq 'raw') {
         return [200, "OK", $content, {'cmdline.skip_format'=>1}];
     } elsif ($args{format} eq 'html') {
@@ -238,7 +248,7 @@ LIMIT 1", {}, @bind);
         my ($infh, $infile) = File::Temp::tempfile(
             "$name.XXXXXXXX", DIR=>$tmpdir, SUFFIX=>".pod");
         my $outfile = "$infile.html";
-        File::Slurper::write_text($infile, $content);
+        File::Slurper::write_binary($infile, $content);
         system(
             "pod2html",
             "--infile", $infile,
@@ -252,7 +262,7 @@ LIMIT 1", {}, @bind);
     } else {
         return [200, "OK", $content, {
             "cmdline.page_result"=>1,
-            "cmdline.pager"=>"pod2man | man -l -"}];
+            "cmdline.pager"=>"pod2man -u | man -l -"}];
     }
 }
 
@@ -271,7 +281,7 @@ App::lcpan::Cmd::doc - Show POD documentation of module/.pod/script
 
 =head1 VERSION
 
-This document describes version 0.80 of App::lcpan::Cmd::doc (from Perl distribution App-lcpan), released on 2016-02-25.
+This document describes version 0.81 of App::lcpan::Cmd::doc (from Perl distribution App-lcpan), released on 2016-03-02.
 
 =head1 FUNCTIONS
 
@@ -314,7 +324,7 @@ Note that currently this command has trouble finding documentation for core
 modules because those are contained in perl release tarballs instead of release
 tarballs of modules, and C<lcpan> is currently not designed to work with those.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
